/*
 * Copyright (C) 2024 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

syntax = "proto3";

package com.android.ranging.generic.proto;

import "packages/modules/Uwb/generic_ranging/proto/src/estimate.proto";

option java_package = "com.android.ranging.generic.proto";
option java_multiple_files = true;

message Event {
  enum Type {
    NONE = 0;
    START = 1;
    STOP = 2;
  }

  Type type = 1;
  float timestamp_sec = 2;
}

message UwbDatum {
  float range_m = 1;
  int32 rssi_dbm = 2;
  float timestamp_sec = 3;
}

message OdometryDatum {
  float x_m = 1;
  float y_m = 2;
  float z_m = 3;
  float timestamp_sec = 8;
}

message InputContainer {
  oneof input {
    UwbDatum uwb_datum = 1;
    OdometryDatum odometry_datum = 3;
  }
}

message LeanEstimate {
  com.android.ranging.generic.proto.Estimate.Status status = 1;
  float range_m = 2;
  float bearing_rad = 3;
  float estimated_beacon_position_error_std_dev_m = 4;
  float timestamp_sec = 5;
}

message DebugLog {
  repeated InputContainer inputs = 1;
  repeated LeanEstimate outputs = 2;
  repeated Event events = 3;
}